@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 21 May 02 15:38:03 tews@ithif51>
  *
  * Bisimilarity theories
  *
- * $Id: bisim_theory.ml,v 1.10 2002/01/24 14:43:58 tews Exp $
+ * $Id: bisim_theory.ml,v 1.12 2002/05/22 13:42:38 tews Exp $
  *
  *)
 
@@ -97,14 +97,17 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
       let ancestor_imports = 
 	List.map 
 	(function
-	   | Resolved_renaming (anc,args,_,_) -> 
+	   | Resolved_renaming (anc,args,_,_,_) -> 
 	       if (count_self_args args) = 0 
 	       then do_const_anc anc args
 	       else do_nonconst_anc anc args
 					(* no other stuff *)
 	   | Unresolved_renaming _
-	   | Resolved_ancestor _ 
-	   | Unresolved_ancestor _ -> (assert(false); raise Internal_error)
+(* NO JAVA ANCESTORS
+ * 	      | Resolved_ancestor _ 
+ * 	      | Unresolved_ancestor _ 
+ *)
+	     -> assert(false)
 	)
 	cl#get_ancestors in
       let components_import = 
@@ -127,7 +130,7 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
 			(modelarg subst_args2) ::
 			subst_args) :: accu
 		 | Spec_sig -> accu
-		 | Spec_Spec -> (assert(false);raise Internal_error)
+		 | Spec_Spec -> assert(false)
 	  ) cl#get_components []
       in
       	Import(
@@ -162,10 +165,10 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
       let self_lifting = (Some rel_expr, Some rel_expr) in
       let ancestor_list = 
 	List.map (function
-		    | Resolved_renaming(oanc, args,_,ianc) -> oanc,args
+		    | Resolved_renaming(oanc, args,_,ianc,_) -> oanc,args
 					(* no other stuff here *)
 		    | Unresolved_renaming _
-		    | _ -> (assert(false); raise Internal_error)
+		    | _ -> assert(false)
 		 ) cl#get_ancestors
       in
       let self_type_arguments = [self#self1_argument; self#self2_argument] in
@@ -318,6 +321,29 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
       self#bisimulation_decl (name_of_public_bibisimulation cl)
 	(name_of_public_class_rel cl)
 
+    method private struct_bisimulation =
+      let sub_ns = sub_space ns in 
+      let (decl1_list, decl2_list, c1_tuple, c2_tuple ) = 
+	self#two_coalgebras_as_tuple sub_ns in
+      let type_of_rel = 	
+	Function(
+	  Product([BoundTypeVariable(self1);
+		   BoundTypeVariable(self2)]),
+	  Bool) in
+      let r = create_one_id sub_ns type_of_rel 
+      in
+	Defn(name_of_private_struct_bibisimulation cl,
+	     [decl1_list; decl2_list; [ Undeclared(r, type_of_rel) ]],
+	     Bool,
+	     Application(
+	       Application(
+		 Term(name_of_private_bibisimulation cl, Always, []),
+		 Tuple([c1_tuple; c2_tuple])
+	       ),
+	       Term(r,Always,[])
+	     ))
+
+
     method private bisim_decl name bisimulation =
       let sub_ns = sub_space ns in
       let type_of_rel = 	
@@ -372,6 +398,7 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
        	self#private_class_rel;
        	self#public_class_rel;
 	self#private_bibisimulation_decl;
+	self#struct_bisimulation;
 	self#public_bibisimulation_decl
       ]
       @ ( 
@@ -599,7 +626,7 @@ class ['class_type, 'member_type] ccsl_pre_bisim_eq_theory
 
     method private imports =
       Import [ccsl_bibisim_theory_name cl, 
-	      self_argument :: self_argument :: orig_arguments]
+              self_argument :: self_argument :: orig_arguments]
 
     method private private_bisimulation_eq_decl =
       Defn( name_of_private_bisimulation_eq cl, 
@@ -947,5 +974,6 @@ class ccsl_req_bisim_theory cl =
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
 
