@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 18:41:48 tews@ithif51>
+ * Time-stamp: <Wednesday 26 June 02 19:57:22 tews@ithif51>
  *
  * the class for ccsl adt's and classes
  *
- * $Id: iface_class.ml,v 1.15 2002/05/22 13:42:40 tews Exp $
+ * $Id: iface_class.ml,v 1.16 2002/07/03 12:01:14 tews Exp $
  *
  *)
 
@@ -541,9 +541,21 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
       match self#get_kind with 
 					(* generate classes *)
   	| Spec_class ->			
-	    [(class_typeconvert (new ccsl_interface_theory self' ));
-	     (class_typeconvert (new ccsl_method_idtype_adt self'));
+	    [
+		(* DOC     \name{class}\texttt{Interface} & *)
+		(* DOC2        signature declaration  *)
+	      (class_typeconvert (new ccsl_interface_theory self' ));
+
+		(* DOC     \name{class}\texttt{Method\_Id} & *)
+		(* DOC2        \raggedright *)
+		(* DOC2        tags for method wise modal operators  *)
+	      (class_typeconvert (new ccsl_method_idtype_adt self'));
+
+		(* DOC    \name{class}\texttt{MethodPredicateLifting} & *)
+		(* DOC2       \raggedright (method wise) predicate lifting, *)
+		(* DOC2       method-wise invariants *)
 	     (class_typeconvert (new ccsl_method_lift_theory self'));
+
 (* 		(class_typeconvert
  * 		   (new ccsl_lift_theory self'));
  * 		(class_typeconvert
@@ -551,17 +563,33 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
  * 		(class_typeconvert
  * 		   (new ccsl_public_invariance_rewrite_theory self'));
  *)
+
+
+		(* DOC     \name{class}\texttt{MethodInvariantRewrite} & *)
+		(* DOC2       utility lemmas for invariants *)
 	     (class_typeconvert
 		(new ccsl_method_invariance_rewrite_theory self'));
+
+		(* DOC     \name{class}\texttt{MethodInvariantInherit} & *)
+		(* DOC2       \raggedright  *)
+		(* DOC2       link methodwise invariants with super classes *)
 	     (class_typeconvert
 		(new ccsl_method_invariance_inherit_theory self'));
+
 (* Jan: what is this GI stuff good for ??
  *	     (class_typeconvert
  *		(new ccsl_greatest_invariance_theory self'));
  * !!!  I also changed the importing in the box theory !!!
  *)
+
+		(* DOC     \name{class}\texttt{Box} & *)
+		(* DOC2       (method wise) modal operators *)
 	     (class_typeconvert
 		(new ccsl_box_theory self'));
+
+		(* DOC     \name{class}\texttt{BoxInherit} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2       link modal operators with super classes *)
 	     (class_typeconvert
 		(new ccsl_box_inherit_theory self'))
 	    ] @ ( 
@@ -576,28 +604,52 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	    ) @ (
 	      if self#has_feature HasBisimulationFeature then
 		[
+
+		(* DOC     \name{class}\texttt{Bisimilarity}% *)
+		(* DOC2        \index{bisimilarity}  & *)
+		(* DOC2        relation lifting and bisimulations *)
 		  (class_typeconvert 
 	             (new ccsl_bibisim_theory self'))
 		] @ (
 		  if self#has_feature HasGreatestBisimFeature
 		  then
 		    [
+
+		(* DOC     \name{class}\texttt{BisimilarityRewrite} & *)
+		(* DOC2       utility lemmas for bisimulations *)
 		      (class_typeconvert 
 			 (new ccsl_private_bibisim_rewrite_theory self'));
+
+		(* DOC     \name{class}\texttt{PublicBisimilarityRewrite} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2       utility lemmas for bisimulations  *)
+		(* DOC2       with respect to the public *)
 		      (class_typeconvert 
 			 (new ccsl_public_bibisim_rewrite_theory self'))
 		    ]
 		  else 
 		    []
 		) @ [
+
+		(* DOC     \name{class}\texttt{BisimilarityEquivalence} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2       bisimulation on one model, bisimilarity *)
 		  (class_typeconvert 
 	             (new ccsl_bisim_eq_theory self'))
 		] @ (
 		  if self#has_feature HasGreatestBisimFeature
 		  then
 		    [
+
+		(* DOC     \name{class}\texttt{BisimilarityEqRewrite} & *)
+		(* DOC2       utility lemmas for bisimilarity *)
 		      (class_typeconvert 
 			 (new ccsl_private_bisim_eq_rewrite_theory self'));
+
+	      (* DOC     \name{class}\texttt{PublicBisimilarityEqRewrite} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2       utility lemmas for bisimilarity with  *)
+		(* DOC2       respect to the public subsignature *)
 		      (class_typeconvert 
 			 (new ccsl_public_bisim_eq_rewrite_theory self'))
 		    ]
@@ -610,6 +662,9 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	      if self#get_rel_lifting_requests = [] then 
 		[]
 	      else 
+
+		(* DOC     \name{class}\texttt{ReqObsEq} & *)
+		(* DOC2       additional liftings *)
 		[ (class_typeconvert
 		     (new ccsl_req_bisim_theory self'))
 		]
@@ -618,8 +673,16 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	      if self#has_feature HasMorphismFeature
 	      then 
 		[
+
+		(* DOC     \name{class}\texttt{Morphism} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        definition of \name{class}--coalgebra  *)
+		(* DOC2 	morphisms *)
 		  (class_typeconvert 
 		     (new ccsl_morphism_theory self'));
+
+		(* DOC     \name{class}\texttt{MorphismRewrite} & *)
+		(* DOC2        utility lemmas for morphisms *)
 		  (class_typeconvert 
 		     (new ccsl_morphism_rewrite_theory self'));
 		]
@@ -627,10 +690,22 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 
 	    ) @ (
 	      [
+
+		(* DOC     \name{class}\texttt{Semantics} & *)
+		(* DOC2        semantics of the specification *)
 		(class_typeconvert 
 	           (new ccsl_semantics_theory self'));
+
+		(* DOC     \name{class}\texttt{Basic} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        utility lemmas for assertions  *)
+		(* DOC2 	and creation conditions *)
 		(class_typeconvert 
 	           (new ccsl_basic_theory self'));
+
+		(* DOC     \name{class}\texttt{FullInvariant} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        full predicate lifting and every combinator *)
 		(class_typeconvert
                    (new ccsl_full_invariant_theory self'));
 	      ] 
@@ -638,6 +713,11 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 
 	      if self#has_feature HasFullRelLiftingFeature then
 		[
+
+		(* DOC     \name{class}\texttt{FullBisimulation} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        full relation lifting  *)
+		(* DOC2        and relevery combinator *)
 		  (class_typeconvert
                      (new ccsl_full_bibisim_theory self'));
 		]
@@ -648,21 +728,52 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	      if self#has_feature HasMorphismFeature
 	      then 
 		[
+
+		(* DOC     \name{class}\texttt{Finality} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        properties of the final  *)
+		(* DOC2        \name{class}--coalgebra, coreduce *)
 		  (class_typeconvert 
 		     (new ccsl_finality_theory self'));
 		]
 	      else []
 
+	    ) @ (
+
+	      if (self#has_feature HasMorphismFeature) &&
+		(self#has_feature HasGreatestBisimFeature)
+	      then 
+		[
+		(* DOC     \name{class}\texttt{FinalityBisim} & *)
+		(* DOC2       Bisimilarity on the final model *)
+		  (class_typeconvert 
+		     (new ccsl_finality_bisim_theory self'));
+		]
+	      else []
+
 	    ) @ (
 
 	      if self#has_feature FinalSemanticsFeature then
 		[
+
+		(* DOC     \name{class}\texttt{Final} & *)
+		(* DOC2        axiomatic final model *)
 		  (class_typeconvert (new ccsl_final_theory self'));
+
+		(* DOC     \name{class}\texttt{FinalProp} & *)
+		(* DOC2        axiom for final model *)
 		  (class_typeconvert (new ccsl_final_props_theory self'));
 		] @ (
 		  if self#has_feature HasMapFeature then
 		    [
+
+		(* DOC     \name{class}\texttt{MapStruct} & *)
+		(* DOC2       \raggedright *)
+		(* DOC2        coalgebra structure for map combinator *)
 		      (class_typeconvert (new ccsl_map_struct_theory self'));
+
+		(* DOC     \name{class}\texttt{Map} & *)
+		(* DOC2        map combinator *)
 		      (class_typeconvert (new ccsl_map_theory self'));
 		    ]
 		  else
@@ -670,11 +781,16 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		)
 	      else
 		[
+
+		(* DOC     \name{class}\texttt{Loose} & *)
+		(* DOC2        axiomatic loose model *)
 		  (class_typeconvert (new ccsl_loose_theory self'));
 		]
 
 	    ) @ (
 
+		(* DOC     \name{class} & *)
+		(* DOC2        top level import theory for \name{class} *)
 	      [
 		(class_typeconvert (new ccsl_coadt_theory self'));
 	      ]
@@ -683,6 +799,9 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 
 	      if self#get_theorems <> [] then
 		[
+
+		(* DOC     \name{class}\texttt{Theorem} & *)
+		(* DOC2        tranlated theorem section *)
 		  class_typeconvert (new ccsl_class_theorem_theory self')
 		]
 	      else
@@ -695,6 +814,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		   if self#has_feature BuildinFeature
 		   then []
 		   else
+		     (* DOC   \name{adt} & data type declaration *)
 		     [adt_typeconvert (new ccsl_pvs_adt_theory self')]
 	       | Isa_mode ->
 		   (if self#has_feature BuildinFeature
@@ -704,13 +824,19 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		   )
 		   @
 		   [
+		     (* DOC   \name{adt}\texttt{Util} & *)
+		     (* DOC2        reduce, accessors, recognisers *)
 		    adt_typeconvert (new ccsl_isa_adtutil_theory self')
 		   ]
 	    ) @ (
 	      if self#has_feature NeedsMapFeature 
 	      then
 		[
+		  (* DOC   \name{adt}\texttt{Map} & map combinator *)
 		  adt_typeconvert (new ccsl_adt_map_theory self');
+
+		  (* DOC   \name{adt}\texttt{Every} & *)
+		  (* DOC2         (full) predicate lifting *)
 		  adt_typeconvert (new ccsl_adt_every_theory self')
 		]
 	      else
@@ -718,6 +844,8 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	    ) @ (
 	      if self#has_feature HasRelLiftFeature
 	      then
+		(* DOC   \name{adt}\texttt{RelLift} & *)
+		(* DOC2             (full) relation lifting *)
 		[adt_typeconvert (new ccsl_adt_rellift_theory self')
 		]
 	      else
