@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Monday 27 May 02 12:04:00 tews@ithif51>
+ * Time-stamp: <Monday 24 June 02 10:22:20 tews@ithif51>
  *
  * the ccsl interface theory
  *
- * $Id: interface_theory.ml,v 1.11 2002/05/30 13:10:30 tews Exp $
+ * $Id: interface_theory.ml,v 1.12 2002/07/03 12:01:14 tews Exp $
  *
  *)
 
@@ -380,12 +380,15 @@ class ['class_type, 'member_type] ccsl_pre_coadt_theory
          @
          (if cl#has_feature HasMorphismFeature
           then 
-	    [
-(* via semantics now
- * 		 ccsl_morphism_rewrite_theory_name cl,[];
- *)
-              ccsl_finality_theory_name cl,[]
-	    ]
+	    if cl#has_feature HasGreatestBisimFeature
+	    then
+	      [
+		ccsl_finality_bisim_theory_name cl,[]
+	      ]
+	    else
+	      [
+		ccsl_finality_theory_name cl,[]
+	      ]
           else [])
 
 	 @
@@ -723,7 +726,7 @@ object (self : 'self)
 
   method private coalg_model_axiom =
     Axiom(
-      name_of_final_prop_axiom,
+      name_of_final_prop_axiom cl,
       Formula(
 	Application(
 	  Term(name_of_finality cl,Always,[]),
