@@ -18,11 +18,11 @@
  *
  * * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Tuesday 28 May 02 16:23:54 tews@ithif51>
+ * Time-stamp: <Monday 24 June 02 17:42:07 tews@ithif51>
  *
  * main compiler driver
  *
- * $Id: main.ml,v 1.17 2002/05/30 13:10:30 tews Exp $
+ * $Id: main.ml,v 1.18 2002/07/03 12:01:15 tews Exp $
  *
  *)
 
@@ -48,6 +48,7 @@ open Feature
 open Class_methods
 open Resolution
 open Newtypecheck
+open Behavioural
 ;;
 
 
@@ -202,6 +203,9 @@ let options =
     ("-c",
      Arg.Set (filter_style),
      "Print on stdout");
+    ("-pedantic",
+     Arg.Set (pedantic_mode),
+     "Enable pedantic consistency checking");
     ("-expert",
      Arg.Set (expert_mode),
      "Expert mode");
@@ -425,6 +429,12 @@ let do_ccsl_ast ast =
   print_verbose( "*** Ccsl_typecheck done (" ^
 		 (string_of_int (Type_variable.number_of_free_variables ())) ^
 		 ")  ***");
+
+  if !pedantic_mode then begin
+    print_verbose( "*** Ccsl pedanticness pass ");
+    ccsl_pedantic_pass (ast); 
+  end;
+    
   let p_ast =
     if !selected_classes_only
     then
@@ -540,6 +550,19 @@ then
     if get_debug_level() <> 0 then
       add_debug_level 1;
 
+    (* pedanticness implications *)
+    if !pedantic_mode then begin
+      if !expert_mode then begin
+	print_error "Strict checking and expert mode are mutually exclusive";
+	exit 1;
+      end;
+      if not !optimize_expressions then begin
+	print_error "Optimizations are required in pedantic mode";
+	exit 1;
+      end;
+    end;
+    
+
     print_verbose compiler_version;
 
     if get_input_files () = []
