@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Jan
  *
- * Time-stamp: <Wednesday 22 May 02 10:24:14 tews@ithif51>
+ * Time-stamp: <Wednesday 22 May 02 18:23:12 tews@ithif51>
  *
  * Liftings and invariants
  *
- * $Id: methodinv_theory.ml,v 1.11 2002/05/22 13:42:41 tews Exp $
+ * $Id: methodinv_theory.ml,v 1.12 2002/05/30 13:10:30 tews Exp $
  *
  *)
 
@@ -936,7 +936,11 @@ class ['class_type, 'member_type] ccsl_pre_method_invariance_inherit_theory
        let mlist = 
 	 List(List.map (fun m -> Term(name_of_method_tag m, Always, []))
 		amethods)
-       in let alist = mlist		(* anticipate change here *)
+       in let alist =			(* anticipate change here *)
+	 List(List.map 
+		(fun m -> Term(name_of_method_tag_string m#last_name, 
+			       Always, []))
+		amethods)
        in
 	 Lemma(
 	   self#lemma_name acl,
