@@ -18,11 +18,11 @@
  *
  * Created 16.03.00 by Jan
  *
- * Time-stamp: <Sunday 26 May 02 19:16:38 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 24 June 02 10:19:45 tews@ithif51>
  *
  * Coalgebra morphism theories
  *
- * $Id: morphism_theory.ml,v 1.11 2002/05/30 13:10:30 tews Exp $
+ * $Id: morphism_theory.ml,v 1.12 2002/07/03 12:01:15 tews Exp $
  *
  *)
 
@@ -671,27 +671,93 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 			   tcc_proof))
 
 
+    method make_body = 
+      [
+      	self#imports;
+	self#coalgebra2_decl;
+	self#finality_existence_decl;
+	self#finality_uniqueness_decl;
+	self#finality_decl;
+	self#struct_coreduce_def;
+	self#coreduce_def
+      ]
+
+    method get_proofs = []
+
+end
+
+class ccsl_finality_theory cl =
+  [ccsl_iface_type, ccsl_member_type] ccsl_pre_finality_theory cl eq_ccsl_types
+
+
+
+(***********************************************************************
+ ***********************************************************************
+ *
+ * Connection between Finality and bisimilarity
+ *
+ *)
+
+
+class ['class_type, 'member_type] ccsl_pre_finality_bisim_theory 
+  (cl : 'class_type) 
+  (* the equality relation for initializing the name space *)
+  (eq_types : ('class_type, 'member_type) top_pre_types
+     -> ('class_type, 'member_type) top_pre_types -> bool)
+
+  : ['class_type, 'member_type] ccsl_pre_class_theory_type =
+  object (self : 'self)
+
+    inherit 
+      ['class_type, 'member_type] ccsl_pre_class_theory_class cl eq_types
+      as top_theory
+
+       (* reserve all names, that we want to declare *)
+    initializer reserve ns 
+       [ name_of_coalgebra;
+       ]
+
+    method get_name = ccsl_finality_bisim_theory_name cl
+
+    method get_parameters = self#simple_parameters 
+
+    initializer top_theory#override_file_name (ccsl_class_file_name cl)
+
+    method private imports =
+      Import(
+	[
+	  ((ccsl_finality_theory_name cl), []) ;
+	]
+      )
+
+
     method private finality_bisim_eq_lemma =
       let sub_ns = sub_space ns in
-      let self2_type = BoundTypeVariable(self2) in
-      let (x1,x2) = match create_ids sub_ns [self2_type;self2_type] with
-	  [a1,t1;a2,t2] -> (a1,a2)
-	| _ -> assert false;
+      let (x1,x2) = 
+	match create_id_pairs sub_ns [Self] with
+	  | [a1,t1],[a2,t2] -> (a1,a2)
+	  | _ -> assert false;
       in
       let x1_term = Term(x1,Never,[]) in
       let x2_term = Term(x2,Never,[]) in
+      let final_assum typ = 
+	Formula(
+	  Application(
+	    Term(name_of_finality cl, Always, 
+		 (TypeArgument typ) :: self#simple_arguments),
+	    coalgebra_term
+	  )
+	)
+      in
 	Lemma(
 	  name_of_finality_bisim_eq_lemma cl,
 	  Implies(
-	    Formula(
-	      Application(
-	      	Term(name_of_finality cl, Never, []),
-		coalgebra2_term
-	      )
-	    ),
+	    And[
+	      final_assum Self;
+	      final_assum (Product[Self;Self])
+	    ],
 	    Forall(
-	      [x1,self2_type;
-	       x2,self2_type],
+	      [(x1,Self); (x2,Self)],
 	      Implies(
 		Formula(
 		  Application(
@@ -700,7 +766,7 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 			   Isabelle_only,
 			   (self#self2_argument :: orig_arguments)
 			  ),
-		      coalgebra2_term
+		      coalgebra_term
 		    ),
 		    Tuple([x1_term;x2_term])
 		  )
@@ -714,27 +780,17 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
     method make_body = 
       [
       	self#imports;
-	self#coalgebra2_decl;
-	self#finality_existence_decl;
-	self#finality_uniqueness_decl;
-	self#finality_decl;
-	self#struct_coreduce_def;
-	self#coreduce_def
+	self#coalgebra_decl;
+	self#finality_bisim_eq_lemma;
       ]
-      @ ( 
-	if cl#has_feature HasGreatestBisimFeature 
-	then
-	  [self#finality_bisim_eq_lemma]
-	else
-	  []
-      )
 
     method get_proofs = []
 
 end
 
-class ccsl_finality_theory cl =
-  [ccsl_iface_type, ccsl_member_type] ccsl_pre_finality_theory cl eq_ccsl_types
+class ccsl_finality_bisim_theory cl =
+  [ccsl_iface_type, ccsl_member_type] ccsl_pre_finality_bisim_theory 
+  cl eq_ccsl_types
 
 
 
