@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Wednesday 22 May 02 18:23:45 tews@ithif51>
+ * Time-stamp: <Tuesday 25 June 02 10:46:03 tews@ithif51>
  *
  * strings for ccsl translation
  *
- * $Id: names.ml,v 1.10 2002/05/30 13:10:30 tews Exp $
+ * $Id: names.ml,v 1.11 2002/07/03 12:01:15 tews Exp $
  *
  *)
 
@@ -42,7 +42,7 @@ let ccsl_interface_theory_name cl = cl#get_name ^ "Interface"
 
 let ccsl_lift_theory_name cl = cl#get_name ^ "PredicateLifting"
 
-let ccsl_method_idtype_adt_name cl = cl#get_name ^ "_Method_Id"
+let ccsl_method_idtype_adt_name cl = cl#get_name ^ "Method_Id"
 				 
 let ccsl_method_lift_theory_name cl = cl#get_name ^ "MethodPredicateLifting"
 				 
@@ -102,6 +102,9 @@ let ccsl_morphism_rewrite_theory_name cl =
 let ccsl_finality_theory_name cl =
   cl#get_name ^"Finality"
 
+let ccsl_finality_bisim_theory_name cl =
+  cl#get_name ^"FinalityBisim"
+
 let ccsl_map_struct_theory_name cl =
   cl#get_name ^"MapStruct"
 
@@ -243,7 +246,7 @@ let name_of_loose_alg_axiom = "loose_constructors"
 
 let name_of_final_coalg_axiom = "final_coalgebra"
 
-let name_of_final_prop_axiom = "final_prop"
+let name_of_final_prop_axiom cl = cl#get_name ^ "_final_prop"
 
 let name_of_final_alg_axiom = "final_constructors"
 
@@ -582,8 +585,8 @@ let name_of_box_inherit_lemma acl = "inherit_box_" ^ acl#get_name
 
 let name_of_full_morphism_pred cl =
   match !output_mode with
-    | Pvs_mode -> cl#get_name ^ "morphism?"
-    | Isa_mode -> cl#get_name ^ "morphism"
+    | Pvs_mode -> cl#get_name ^ "Morphism?"
+    | Isa_mode -> cl#get_name ^ "Morphism"
 
 let name_of_full_morphism_struct_pred cl =
   match !output_mode with
@@ -592,8 +595,8 @@ let name_of_full_morphism_struct_pred cl =
 
 let name_of_public_morphism_pred cl =
   match !output_mode with
-    | Pvs_mode -> cl#get_name ^ "public_morphism?"
-    | Isa_mode -> cl#get_name ^ "public_morphism"
+    | Pvs_mode -> cl#get_name ^ "Public_morphism?"
+    | Isa_mode -> cl#get_name ^ "Public_morphism"
 
 (*******************************************************************
  *
