@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 20 May 02 12:32:33 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 24 June 02 16:52:04 tews@ithif51>
  *
  * Typechecking with unification
  *
- * $Id: newtypecheck.ml,v 1.16 2002/05/22 13:42:42 tews Exp $
+ * $Id: newtypecheck.ml,v 1.17 2002/07/03 12:01:16 tews Exp $
  *
  *
  * the algorithm is homegrown and works in two passes
@@ -215,7 +215,7 @@ let proj_dom_error loc domtype =
 
 let invalid_definition loc construct =
   error_message loc
-    (construct ^ " not allowed in definitional extension.");
+    (construct ^ " is not allowed in definitional extension.");
   raise Typecheck_error
 
 let d s = 
@@ -305,15 +305,13 @@ let rec unify tv_bindings t1 t2 =
   let recurse_arg = unify_arg tv_bindings 
   in
     (match t1,t2 with
-       | Groundtype(id1,args1), Groundtype(id2,args2) -> 
-	   if id1.id_token.token_name = id2.id_token.token_name
-	   then
+       | Groundtype(id1,args1), Groundtype(id2,args2) when
+	   id1.id_token.token_name = id2.id_token.token_name ->
 	     begin
+(* HENDRIK: this assertion can be triggered with overloading groundtypes *)
 	       assert((List.length args1) = (List.length args2));
 	       Groundtype(id1, List.map2 recurse_arg args1 args2)
 	     end
-	   else
-	     raise Unify
        | BoundTypeVariable id1, BoundTypeVariable id2 ->
 	   if id1.id_token.token_name = id2.id_token.token_name 
 	   then
@@ -968,7 +966,8 @@ and check_formula ccl loc tv_bindings formula_type formula =
 			 (string_of_ccsl_type neq_typ) ^
 			 " for equality")
 	  in
-	    Equal( recurse_exp neq_typ ex_a, recurse_exp neq_typ ex_b)
+	    Equal( TypeAnnotation(recurse_exp neq_typ ex_a, eq_typ),
+		   recurse_exp neq_typ ex_b)
 
 					(* Equal needs TypeAnnotation *)
       | Equal _ -> assert(false)
@@ -1678,8 +1677,12 @@ and check_valid_definition_form loc formula =
       | Forall(decll, f) -> recurse_form f
       | Exists(decll, f) -> recurse_form f
       | Formula ex -> recurse_exp ex
-      | Obseq(t,ex1,ex2) -> 
-	  invalid_definition loc "Observational equality"
+      | Obseq(Some(obsname, eq_typ), ex1,ex2) -> 
+	  if count_self eq_typ <> 0 
+	  then
+	    invalid_definition loc "Observational equality involving Self"
+
+      | Obseq _ 
 					(* not in ccsl_input_formulas *)
       | MetaImplies _
       | MetaForall _
