@@ -18,11 +18,11 @@
  *
  * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 21:09:07 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Sunday 23 June 02 14:38:41 tews@ithif56.inf.tu-dresden.de>
  *
  * Utility functions for ccsl parser
  *
- * $Id: parser.ml,v 1.24 2002/05/22 13:42:42 tews Exp $
+ * $Id: parser.ml,v 1.25 2002/07/03 12:01:16 tews Exp $
  *
  *)
 
@@ -708,15 +708,22 @@ let add_groundterm token membersort parameters typ formulaoption =
       add_member_to_iface m;
       (match formulaoption with
 	 | None -> ()
-	 | Some f -> (let def =
-			{ defined_method = m;
+	 | Some f -> 
+	     (let def = { defined_method = m;
 			  variables = [];
 			  definition = f;
 			  def_sequence = -1;
 			}
-		      in
-			gsig#add_definition def
-		     )
+	      in
+		if debug_level _DEBUG_PARSERCHECK then
+		  (match f with
+		     | Symbolic f -> print_verbose
+			 ("Def " ^ token.token_name ^ " : " ^
+			  string_of_ccsl_formula f)
+		     | _ -> ()
+		  );
+		gsig#add_definition def
+	     )
       );
     end
 
@@ -929,6 +936,13 @@ let do_definition token dom codom equation =
 	def_sequence = -1;
       }
   in
+    if debug_level _DEBUG_PARSERCHECK then
+      (match equation with
+	 | Symbolic f -> print_verbose
+	     ("Def " ^ token.token_name ^ " : " ^
+	      string_of_ccsl_formula f)
+	 | _ -> ()
+      );
     (ciface())#add_definition def
   
 
@@ -984,7 +998,7 @@ let do_assertion token (selfvar,varlist) formula =
     if debug_level _DEBUG_PARSERCHECK then
       (match formula with
 	 | Symbolic f -> print_verbose
-	     ("Ass " ^ token.token_name ^ " " ^
+	     ("Ass " ^ token.token_name ^ " : " ^
 	      string_of_ccsl_formula f)
 	 | _ -> ()
       );
@@ -1007,7 +1021,7 @@ let do_creation token varlist formula =
     if debug_level _DEBUG_PARSERCHECK then
       (match formula with
 	 | Symbolic f -> print_verbose
-	     ("Ass " ^ token.token_name ^ " " ^
+	     ("Crea " ^ token.token_name ^ " : " ^
 	      string_of_ccsl_formula f)
 	 | _ -> ()
       );
@@ -1082,7 +1096,7 @@ let do_theorem token varlist formula =
     if debug_level _DEBUG_PARSERCHECK then
       (match formula with
 	 | Symbolic f -> print_verbose
-	     ("Ass " ^ token.token_name ^ " " ^
+	     ("Theorem " ^ token.token_name ^ " : " ^
 	      string_of_ccsl_formula f)
 	 | _ -> ()
       );
