@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 20:02:34 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Tuesday 25 June 02 14:55:52 tews@ithif51>
  *
  * Resolution pass for CCSL
  *
- * $Id: resolution.ml,v 1.14 2002/05/22 13:42:43 tews Exp $
+ * $Id: resolution.ml,v 1.15 2002/07/03 12:01:16 tews Exp $
  *
  *)
 
@@ -172,7 +172,9 @@ let rec do_basic_expr ccl loc = function
                     else		(* export everything *)
 		      export_member topiface m mfulltype
 		in let _ = dr ("member " ^ 
-			       (string_of_ccsl_inst_iface instiface)
+			       (string_of_ccsl_inst_iface instiface) ^
+			       token.token_name ^ " : " ^
+			       (string_of_ccsl_type memtyp)
 			      )
 		in		    
 		  TypeAnnotation(
@@ -596,7 +598,7 @@ let do_assertion ccl assertion =
 (* Process a definition in a ground signature or in a class
  * 
  * From the parser the definition comes in as a formula, which 
- * is should better be an equation.
+ * should better be an equation.
  * From the left hand side of the equation I extract variable declarations, 
  * by matching these variables against the declared type.
  * After that the left hand side is thrown away, the extracted variables 
@@ -720,6 +722,12 @@ let do_symbolic_definition iface def =
 	| (ExprLoc _ as singlearg) :: restargs, 
 	  Function(typ, codomain) ->
 	    recurse restargs codomain [make_arg_id typ singlearg]
+	| _ , Groundtype(idrec, args) when is_type_def idrec ->
+	    (* do not use recurse here, 
+	     * because we ded not produce any binding
+	     *)
+	    match_args argslist (expand_type_def eq_ccsl_types funtype)
+
 	| [], resttyp -> [], resttyp
 	| ExprLoc(_, loc) :: _, _ ->
 	    error_message loc "Superfluous variable.";
@@ -780,6 +788,13 @@ let do_class ccl =
 	ccl#get_definitions;
       assert(Symbol.nesting_size() = nest + 1);
 
+         (* make class specials available in assertions *)
+      List.iter (fun mem -> (if mem#get_sort = Class_Special
+			     then
+			       Symbol.create_member mem)
+		)
+	ccl#get_members;
+
       (* print_verbose( "Symboltable: " );
        * print_verbose (Symbol.symbol_table_dump 
        * 			  Top_variant_types_util.dump_symbol_brief);
