@@ -18,11 +18,11 @@
  *
  * Created 3.11.99 by Hendrik
  *
- * Time-stamp: <Tuesday 28 May 02 17:33:18 tews@ithif51>
+ * Time-stamp: <Wednesday 5 June 02 22:46:44 tews@ithif56.inf.tu-dresden.de>
  *
  * Semantics
  *
- * $Id: semantics_theory.ml,v 1.14 2002/05/30 13:10:31 tews Exp $
+ * $Id: semantics_theory.ml,v 1.15 2002/07/03 12:01:16 tews Exp $
  *
  *)
 
@@ -620,20 +620,32 @@ class ['class_type, 'member_type] ccsl_pre_basic_theory
 	      in 
 		(* For PVS snip the first forall off the assertion 
 		   and merge it with the quantifier for the coalgebra
+		   Snip further the assumption and merge it with
+		   the assertions assumption
 		*)
-	      let (all_decl, all_body) = match pre_pretty_ass with
+	      let (all_decl, pre_all_body) = match pre_pretty_ass with
 		| Forall(decllist, body) -> (decllist, body)
 		| x -> ([], x)
+	      in let (assum_list, concl_body) = match pre_all_body with
+		| Implies(And(assum_list), concl) -> assum_list, concl
+		| Implies(assum, concl) -> [assum], concl
+		| x -> [], x
 	      in
 		match !output_mode with
 		  | Pvs_mode -> 
 		      Forall(
 			(name_of_coalgebra, self#coalgebra_type) ::
-			x_decl :: (List.map decl_from_rec ass.free_variables)
-			@ all_decl,
+			  x_decl :: (List.map decl_from_rec ass.free_variables)
+			  @ all_decl,
 			Implies(
-			  self#assert_coalgebra_hypothesis,
-			  all_body))
+			  (if assum_list = [] 
+			   then self#assert_coalgebra_hypothesis
+			   else
+			     And( self#assert_coalgebra_hypothesis :: 
+				    assum_list)
+			  ),
+			       concl_body)
+		      )
 		  | Isa_mode -> 
 		      MetaImplies(
 			self#assert_coalgebra_hypothesis,
