@@ -18,11 +18,11 @@
  *
  * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Tuesday 28 May 02 18:15:45 tews@ithif51>
+ * Time-stamp: <Monday 24 June 02 17:44:21 tews@ithif51>
  *
  * global control variables of the loop compiler
  *
- * $Id: global.mli,v 1.11 2002/05/30 13:10:31 tews Exp $
+ * $Id: global.mli,v 1.12 2002/07/03 12:01:17 tews Exp $
  *
  *)
 
@@ -60,6 +60,16 @@ val output_mode : output_mode ref
 (* val parse_prelude : bool ref *)
 
 
+    (* exceptions for -pedantic errors *)
+exception PedanticViolation
+
+    (* do pedantic consistency checking, 
+     * let only Martin Roessigers functors pass
+     * set via -pedantic
+     *)
+val pedantic_mode : bool ref
+
+
     (* 
      * do things, a normal user should never see
      * set via -expert
@@ -201,6 +211,9 @@ val dependent_assertions : bool ref
      * 128 : print information about symbol table
      * 512 : print information about unification
      * 1024 : print assertion/creation condition right after parsing
+     * 2048 : variance pass
+     * 4096 : feature pass
+     * 8192 : pedanticness pass
      * set in main.ml, via -D [int] option
      *)
 val _VERBOSE :                 int 
@@ -216,6 +229,7 @@ val _DEBUG_UNIFICATION :       int
 val _DEBUG_PARSERCHECK :       int
 val _DEBUG_VARIANCE :	       int
 val _DEBUG_FEATURES : 	       int
+val _DEBUG_STRICT : 	       int
 
     (* access functions for debug_level_var
      *)
