@@ -18,11 +18,11 @@
  *
  * Created 26.2.99 by Joachim
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Monday 11 March 02 11:47:20 tews@ithif51>
  *
  * Isabelle pretty printer
  *
- * $Id: isabelle_pretty.ml,v 1.18 2002/01/23 16:00:22 tews Exp $
+ * $Id: isabelle_pretty.ml,v 1.19 2002/05/03 15:01:17 tews Exp $
  *
  *)
 
@@ -97,7 +97,7 @@ let rec isa_pp_top_type
        * into some Adt(adt, flag, args).
        *)
 
-	(assert(false); raise Internal_error)
+	assert(false)
     | Function(dom, codom) ->
 	begin
 	  open_box 0;
@@ -113,7 +113,7 @@ let rec isa_pp_top_type
 	end	
     | SmartFunction(doml,codom) ->
 	(match doml with
-	   | [] -> (assert(false); raise Internal_error)
+	   | [] -> assert(false)
 	   | tl -> isa_pp_top_type
 		 (List.fold_right (fun t res -> Function(t, res))
 		    tl codom))
@@ -191,7 +191,7 @@ let rec isa_pp_top_type
 			      name_of_array_of_primitive s (string_of_int dim)
 			  | Class(c, _) ->
 			      name_of_array_of_class c (string_of_int dim)
-			  | _ -> assert false; raise Internal_error
+			  | _ -> assert false
 		       );	
 	  close_box()
 	end
@@ -205,14 +205,14 @@ let rec isa_pp_top_type
 	  close_box()
 	end			
 					(* not allowed *)
-    | FreeTypeVariable _ -> (assert(false); raise Internal_error)
+    | FreeTypeVariable _ -> assert(false)
 
 and isa_pp_top_basic_expression = function
     | TermVar idc ->
 	print_string (resolution_of idc).id_token.token_name
     | Member(ex, m) ->
 			(* Members are treted in the prepretty printer *)
-	(assert false; raise Internal_error)
+	assert false
 
 
 and isa_pp_top_expression 
@@ -441,7 +441,7 @@ and isa_pp_top_expression
 
     | SmartApplication(func, arg_list) ->
 	(match arg_list with
-	   | [] -> (assert(false); raise Internal_error)
+	   | [] -> assert(false)
 	   | tl -> isa_pp_top_expression 
 		 (List.fold_left (fun res t -> Application(res, t))
 		    func tl))
@@ -677,7 +677,8 @@ and isa_pp_top_expression
 	     | Groundtype(id,_) -> 
 		 Term(name_of_const_every id.id_token.token_name,
 		      Always,[])
-	     | _ -> assert(false); raise Internal_error)
+	     | _ -> assert(false)
+	  )
 	in
 	  isa_pp_top_expression
 	    (if expr_list = [] 
@@ -706,7 +707,8 @@ and isa_pp_top_expression
 	     | Groundtype(id,_) -> 
 		 Term(name_of_const_rel_every id.id_token.token_name,
 		      Always,[])
-	     | _ -> assert(false); raise Internal_error)
+	     | _ -> assert(false)
+	  )
 	in
 	  isa_pp_top_expression
 	    (if expr_list = [] 
@@ -727,7 +729,8 @@ and isa_pp_top_expression
 	     | Groundtype(id,_) -> 
 		 Term(name_of_const_map id.id_token.token_name,
 		      Always,[])
-	     | _ -> assert(false); raise Internal_error)
+	     | _ -> assert(false)
+	  )
 	in
 	  isa_pp_top_expression
 	    (if expr_list = [] 
@@ -779,7 +782,7 @@ and isa_pp_top_expression
     | MethodSelection _
     | Box _
     | Diamond _ ->
-      	(assert(false); raise Internal_error)
+      	assert(false)
 	
 
 	
@@ -917,41 +920,14 @@ and isa_pp_top_formula (* : top_formulas -> unit *)
 		     Term(name_of_greatest_bisim cl, Always, []),
 		     [Term(cl_name,Always,[]);Term(cl_name,Always,[])]
 		   )
-	     | _ -> assert(false); raise Internal_error)
+	     | _ -> assert(false)
+	  )
 	in
 	  isa_pp_top_expression
 	    (Application(
 	       bisim_term, 
 	       Tuple([ex1;ex2])))	      
 
-(* DELETE
- * 					   (* now in pre pretty printing *)
- * (* Hendrik: clean this up when components and full liftings work
- *   the problem is that opt_formula may generate Bisim
- *   and here we call name_of_greatest_bisim
- * *)
- * 	   let name_of_bisim =
- * 	     (match typ with
- * 		| Class(cl,_) -> name_of_greatest_bisim cl
- * 		| Adt(adt,_,_) -> name_of_greatest_bisim adt
- * 		| _ -> assert(false); raise(Internal_error))
- * 	   in
- * 	      begin
- * 		open_box 0;					    (* 1 *)
- * 		print_string name_of_bisim; 
- * 		print_cut();
- * 		print_string "(";
- * 		open_box 0;					    (* 2 *)
- * 		isa_pp_top_expression ex1;
- * 		print_string ",";
- * 		print_space();
- * 		isa_pp_top_expression ex2;
- * 		close_box();					    (* 2 *)
- * 		print_string ")";
- * 		close_box()					    (* 1 *)
- * 	      end
- *)
-
     | MetaImplies (prem_expr, concl_expr) ->
 	begin
 	  open_box 0;
@@ -977,7 +953,7 @@ and isa_pp_top_formula (* : top_formulas -> unit *)
 		 isa_pp_top_formula form;
 	       end) 
     | Obseq _ ->
-	assert false; raise Internal_error
+	assert false
 
 
 
@@ -1377,7 +1353,7 @@ let isa_pp_theory theory =
           close_box()
       | Datatype ->
 				(* datatypes are in ordinary theories *)
-	  (assert(false); raise Internal_error)
+	  assert(false)
 ;;
 
 
@@ -1416,7 +1392,7 @@ let isa_pp_proof th =
 		 (* include the following line, 
                   * if the top_pre_proof_file_entry variant is
 		  * extended to generate PVS proof files.
-		    | _ -> assert false; raise Internal_error
+		    | _ -> assert false
 		  *)
     )
     th#get_proofs
@@ -1437,5 +1413,6 @@ let isa_pp_proof th =
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
 
