@@ -18,11 +18,11 @@
  *
  * Created 11.11.99 by Hendrik
  *
- * Time-stamp: <Thursday 16 May 02 1:21:17 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Friday 21 June 02 16:39:25 tews@ithif51>
  *
  * substitution and optimization for top_types
  *
- * $Id: logic_util.ml,v 1.20 2002/05/22 13:42:45 tews Exp $
+ * $Id: logic_util.ml,v 1.21 2002/07/03 12:01:17 tews Exp $
  *
  *)
 
@@ -913,7 +913,6 @@ let rec do_opt_formula = function
   | Forall(var1,f) ->
       (match do_opt_formula f with
 	 | True -> True
-	 | False -> False
 	 | Forall(var2,f')-> Forall(var1@var2, f')
 	 | f' -> Forall(var1,f'))
   | Exists(var1, f) ->
