@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Saturday 11 May 02 19:24:32 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Saturday 25 May 02 1:07:36 tews@ithif56.inf.tu-dresden.de>
  *
  * utility functions for pvs proofs
  *
- * $Id: pvs_proof_util.ml,v 1.4 2002/05/22 13:42:46 tews Exp $
+ * $Id: pvs_proof_util.ml,v 1.5 2002/05/30 13:10:31 tews Exp $
  *
  *)
 
@@ -35,6 +35,9 @@ let apply_command c l = LList([LAtom c] @ l)
 
 let string_atom s = LAtom("\"" ^ s ^ "\"")
 
+let apply_command_string_list c l = 
+  apply_command c (List.map string_atom l)
+
 (*******************************************************************
  * PVS proof commands in alphabetical order 
  *)
@@ -42,36 +45,36 @@ let string_atom s = LAtom("\"" ^ s ^ "\"")
 let apply c = apply_command "APPLY" [c]
 
 let auto_rewrite names = 
-  apply_command "AUTO-REWRITE" (List.map (fun s -> string_atom s) names)
+  apply_command_string_list "AUTO-REWRITE" names
 
 let auto_rewrite_defs = simple_command "AUTO-REWRITE-DEFS"
 
 let auto_rewrite_theories thl = 
-  apply_command "AUTO-REWRITE-THEORIES" 
-    (List.map (fun th -> LAtom ("\"" ^ th ^ "\"")) thl)
+  apply_command_string_list "AUTO-REWRITE-THEORIES" thl
 
 let pvs_assert = simple_command "ASSERT"
 
 let branch step steplist = apply_command "BRANCH" [step;LList(steplist)]
 
-let case ex = LList( [ LAtom("CASE "); 
-			       string_atom ex ])
+let case ex = LList( [ LAtom("CASE"); 
+		       string_atom ex ])
 
-let expand name = LList( [ LAtom("EXPAND "); 
+let expand name = LList( [ LAtom("EXPAND"); 
 			       string_atom name ])
 
-let expand_num name i = LList( [ LAtom("EXPAND "); 
+let expand_num name i = LList( [ LAtom("EXPAND"); 
 				       string_atom name;
 				       LAtom(string_of_int i)])
 
 let expand_nums name i j =
   if j=0 then expand_num name i else
-  	LList( [ LAtom("EXPAND "); 
+  	LList( [ LAtom("EXPAND"); 
 		 string_atom name;
 		 LAtom(string_of_int i);
-		 LAtom(" ");
 		 LAtom(string_of_int j)])
 
+let expand_star name_list = apply_command_string_list "EXPAND*" name_list
+
 let extensionality = simple_command "APPLY-EXTENSIONALITY :hide? t"
 
 let fail = simple_command "FAIL"
@@ -84,12 +87,11 @@ let grind = simple_command "GRIND"
 
 let hide sequent = apply_command "HIDE" [LAtom(string_of_int sequent)]
 
-let hide_nums num_list = LList(LAtom("HIDE")
-			       ::
-			       (List.map
-				  (fun i ->
-				     LAtom(" " ^ (string_of_int i)))
-				  num_list))
+let hide_nums num_list = apply_command "HIDE" 
+			   (List.map
+			      (fun i ->
+				 LAtom(string_of_int i))
+			      num_list)
 
 let hide_all_but keep_list = 
   LList((LAtom "HIDE-ALL-BUT") ::
@@ -101,7 +103,7 @@ let induct name = LList( [ LAtom("INDUCT");
 
 let inst_question = simple_command "INST?"
 
-let inst_num i = LList( [ LAtom("INST? "); 
+let inst_num i = LList( [ LAtom("INST?"); 
 			       LAtom( string_of_int i ) ])
 
 let inst_val i name = LList( [ LAtom "INST"; 
@@ -109,21 +111,21 @@ let inst_val i name = LList( [ LAtom "INST";
 			       string_atom name])
 
 
-let lemma name = LList( [ LAtom("LEMMA "); 
+let lemma name = LList( [ LAtom("LEMMA"); 
 			       string_atom name ])
 
 let liftif = simple_command "LIFT-IF"
 
-let liftif_num i = LList( [ LAtom("LIFT-IF "); 
+let liftif_num i = LList( [ LAtom("LIFT-IF"); 
 			       LAtom( string_of_int i ) ])
 
-let name shortname longname = LList( [ LAtom("NAME "); 
+let name shortname longname = LList( [ LAtom("NAME"); 
 			               string_atom shortname;
                                        string_atom longname ])
 
 let split = simple_command "SPLIT"
 
-let split_num i = LList( [ LAtom("SPLIT "); 
+let split_num i = LList( [ LAtom("SPLIT"); 
 			       LAtom( string_of_int i ) ])
 
 let postpone = simple_command "POSTPONE"
@@ -134,13 +136,15 @@ let reduce = simple_command "REDUCE"
 
 let repeat c = apply_command "REPEAT" [c]
 
-let replace_num i = LList( [ LAtom("REPLACE "); 
+let replace_eta name = apply_command "REPLACE-ETA" [string_atom name]
+
+let replace_num i = LList( [ LAtom("REPLACE"); 
 			       LAtom( string_of_int i ) ])
 
-let rewrite name = LList( [ LAtom("REWRITE "); 
+let rewrite name = LList( [ LAtom("REWRITE"); 
 			       string_atom name ])
 
-let rewrite_left name = LList( [ LAtom("REWRITE "); 
+let rewrite_left name = LList( [ LAtom("REWRITE"); 
 				 string_atom name;
 				 LAtom(":DIR");
 				 LAtom("RL")])
@@ -159,12 +163,12 @@ let pvs_then steplist = apply_command "THEN" steplist
 
 let then_affe (* steplist *) = apply_command "THEN@" (* steplist *)
 
-let type_pred name = LList( [ LAtom("TYPEPRED "); 
+let type_pred name = LList( [ LAtom("TYPEPRED"); 
 			      string_atom name ])
 
 let pvs_try c then_ else_ = apply_command "TRY" [c;then_;else_]
 
-let use name = LList( [ LAtom("USE "); 
+let use name = LList( [ LAtom("USE"); 
 			       string_atom name ])
 
 
