@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Bart
  *
- * Time-stamp: <Sunday 19 May 02 16:09:20 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Monday 24 June 02 11:56:38 tews@ithif51>
  *
  * top level type definitions
  *
- * $Id: top_variant_types.ml,v 1.25 2002/05/22 13:42:47 tews Exp $
+ * $Id: top_variant_types.ml,v 1.26 2002/07/03 12:01:17 tews Exp $
  *
  *)
 
@@ -139,7 +139,8 @@ type variance_type =
   | Pair of int * int
 
 type functor_type =
-  | UnknownFunctor
+  | UnknownFunctor			(* initial value until variance pass *)
+        (* prefix Strictly means: All type parameters are strictly positive *)
   | StrictlyConstantFunctor
   | ConstantFunctor
   | StrictlyPolynomialFunctor
