@@ -18,11 +18,11 @@
  *
  * * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Tuesday 21 May 02 17:36:04 tews@ithif51>
  *
  * Utility functions for variant types
  *
- * $Id: top_variant_types_util.ml,v 1.20 2002/01/24 14:44:03 tews Exp $
+ * $Id: top_variant_types_util.ml,v 1.22 2002/05/22 13:42:47 tews Exp $
  *
  *)
 
@@ -46,19 +46,13 @@ open Type_variable
 let resolution_of = function
   | Resolved r -> r
   | Unresolved _ ->
-      assert false;
-      raise Internal_error;;
+      assert false
 
 
 let ancestor_resolution_of = function
-  | Resolved_ancestor r -> r
-  | Resolved_renaming (_, _, _, icl) -> icl
-  | Unresolved_ancestor _ ->
-      assert false;
-      raise Internal_error
+  | Resolved_renaming (_, _, _, icl,_) -> icl
   | Unresolved_renaming _ ->
-	 assert false;
-	 raise Internal_error;;
+	 assert false
 
 
 
@@ -88,8 +82,8 @@ let dump_token = string_of_token;;
 let dump_origin = function
   | CCSL_TypeParameter -> "CCSL Type Param"
   | CCSL_Var -> "CCSL Var"
-  | CCSL_TypeAbbrev -> "CCSL Type Abbrev"
-  | CCSL_GroundType _ -> "CCSL Ground Type"
+  | CCSL_GroundTypeDecl _ -> "CCSL Ground Type"
+  | CCSL_GroundTypeDef _ -> "CCSL Ground Type"
   | CCSL_Output     -> "CCSL back end"
 
 
@@ -237,7 +231,7 @@ and dump_top_type = function
 and dump_inst_iface = function
   | NoIface -> ""
   | CurrentIface -> "Self::"
-  | InstIface(iface,arg_list) ->
+  | InstIface(iface,arg_list,locopt) ->
       iface#get_name ^ "[" ^
       (dump_list dump_argument " , " arg_list) ^
       "]::"
@@ -614,9 +608,12 @@ and dump_var_record id =
 			   (* logical Variable in CCSL Assertions *)
      | CCSL_Var -> ", " ^ dump_top_type id.id_type
 			(* ccsl type abbreviation *)
-     | CCSL_TypeAbbrev -> ", " ^ dump_top_type id.id_type
+     | CCSL_GroundTypeDef _ ->
+	 "[" ^ (dump_list dump_parameter ", " id.id_parameters) ^ 
+	 " = " ^ (dump_top_type id.id_type) ^ "]"
+
 			(* ccsl ground type *)
-     | CCSL_GroundType _ -> 
+     | CCSL_GroundTypeDecl _ -> 
 	 "[" ^ (dump_list dump_parameter ", " id.id_parameters) ^ "]"
 			(* ccsl ground term *)
      | CCSL_Output -> ""
@@ -635,7 +632,6 @@ and dump_var_record id =
 
 let dump_symbol (* : top_symbol_type -> string *) = function
   | CCSL_GroundTypeSymb id -> "Groundtype " ^ (dump_var_record id)
-  | CCSL_TypeAbbrevSymb id -> "Abbrev " ^ (dump_var_record id)
   | TypevarSymb id -> "Typevar " ^ (dump_var_record id)
   | VarSymb id -> "Var " ^ (dump_var_record id)
   | MemberSymb m -> "Member " ^ m#dump_member
@@ -657,7 +653,6 @@ let dump_symbol (* : top_symbol_type -> string *) = function
 
 let dump_symbol_brief (* : top_symbol_type -> string *) = function
   | CCSL_GroundTypeSymb id -> "Groundtype " ^ id.id_token.token_name
-  | CCSL_TypeAbbrevSymb id -> "Abbrev " ^ id.id_token.token_name
   | TypevarSymb id -> "Typevar " ^ id.id_token.token_name
   | VarSymb id -> "Var " ^ id.id_token.token_name
   | MemberSymb m -> "Member " ^ m#get_name
@@ -678,20 +673,22 @@ let dump_symbol_brief (* : top_symbol_type -> string *) = function
 (* Because this module is a big mess ;-) *)
 (* Even more puzzling: why is nobody using either of these two ? *)
 let dump_ancestor (* : top_ancestor_type -> string *) = function
-  | Unresolved_ancestor token_list ->
-      "Unresolved " ^ 
-      (List.fold_left
-	 (fun res token ->
-	    res ^ "." ^ dump_token token)
-	 ""
-	 token_list)
-  | Resolved_ancestor ifa ->
-      "Resolved (" ^ ifa#dump_iface ^ ")"
-  | Unresolved_renaming (ifa, al, renaming ) ->
+(* NO JAVA ANCESTORS
+ *   | Unresolved_ancestor token_list ->
+ * 	 "Unresolved " ^ 
+ * 	 (List.fold_left
+ * 	    (fun res token ->
+ * 	       res ^ "." ^ dump_token token)
+ * 	    ""
+ * 	    token_list)
+ *   | Resolved_ancestor ifa ->
+ * 	 "Resolved (" ^ ifa#dump_iface ^ ")"
+ *)
+  | Unresolved_renaming (ifa, al, renaming, loc ) ->
       "Unresolved (" ^ ifa#dump_iface ^ "[" ^ 
       (dump_list dump_argument ", " al) ^
       " renaming ...]"
-  | Resolved_renaming (_, al, member_list, iifa) ->
+  | Resolved_renaming (_, al, member_list, iifa, loc) ->
       "Resolved (" ^ iifa#dump_iface ^ "[" ^ 
       (dump_list dump_argument ", " al) ^
       " renaming " ^
@@ -708,8 +705,6 @@ let dump_ancestor (* : top_ancestor_type -> string *) = function
 
 let dump_top_ast ast : string = 
   let dump = function 
-    | CCSL_TypeAbbrev_dec id -> 
-	  id.id_token.token_name ^ " = " ^ (dump_top_type id.id_type)
     | CCSL_class_dec cl ->  cl#dump_iface
     | CCSL_adt_dec adt  -> adt#dump_iface
     | CCSL_sig_dec si -> si#dump_iface
@@ -724,4 +719,5 @@ let dump_top_ast ast : string =
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
